/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2009, Red Hat Middleware LLC, and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package test;

import org.jboss.weld.BeanManagerImpl;
import org.jboss.weld.environment.se.StartMain;
import org.testng.Assert;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;
import org.jboss.weld.context.SessionContext;
import org.jboss.weld.context.beanstore.HashMapBeanStore;

import javax.enterprise.context.spi.CreationalContext;
import javax.enterprise.inject.spi.BeanManager;
import javax.enterprise.inject.spi.Bean;

public class Attic2Test {
    
    private BeanManager beanManager;
    
    @BeforeClass
    public void Setup() {
        StartMain startMain = new StartMain(new String[0]);
        beanManager = startMain.go();
    }
    
    @Test
    public void test1() throws Exception {
        BeanManagerImpl bmImpl = (BeanManagerImpl)beanManager;
        SessionContext sc = new SessionContext();
        sc.setActive(true);
        sc.setBeanStore(new HashMapBeanStore());
        bmImpl.addContext(sc);
        
        Bean<Torch> lightBean = (Bean<Torch>)beanManager.getBeans(Torch.class).iterator().next();
        CreationalContext<Torch> lightCc = beanManager.createCreationalContext(lightBean);
        Torch light = (Torch)beanManager.getReference(lightBean, Torch.class, lightCc);
        light.setState("bright");
        
        Bean<Attic> roomBean = (Bean<Attic>)beanManager.getBeans(Attic.class).iterator().next();
        CreationalContext<Attic> roomCc = beanManager.createCreationalContext(roomBean);
        Attic room = (Attic)beanManager.getReference(roomBean, Attic.class, roomCc);
        Assert.assertEquals(room.getLightState(), "bright");
    }
}
